package
Version:
v0.0.12
Opens a new window with list of versions in this module.
Published: Dec 21, 2018
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Backoff struct {
Seq []int
}
Backoff represents a back-off strategy
Seq represents a seqence of durations in seconds to backoff for
Duration returns a duration to backoff for given the step number n.
The duration is jittered by +- 500ms
Source Files
¶
Click to show internal directories.
Click to hide internal directories.